CoordinateUtil class

Utility class for handling coordinate translations and checks.

Constructors

CoordinateUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hasPointInRange(RRect focusedRRect, Rect textRect) → bool
Checks if a point represented by a rectangle is within the range of another rounded rectangle.
translateX({required double x, required Size canvasSize, required Size imageSize, required InputImageRotation rotation, required CameraLensDirection cameraLensDirection}) → double
Translates the X coordinate based on canvas and image size, rotation, and camera lens direction.
translateY({required double y, required Size canvasSize, required Size imageSize, required InputImageRotation rotation, required CameraLensDirection cameraLensDirection}) → double
Translates the Y coordinate based on canvas and image size, rotation, and camera lens direction.